# LomPy

LomPy is a python library for the multiscale analysis of marked point processes. It is an open-source platform that merges concepts and methods from quantitative geography, signal processing, and the physical sciences to derive local multifractal parameters at arbitrary spatial resolutions. It is specifically designed to process and analyze data that are either irregularly spaced or possess large data holes over spatial or temporal domains.

The core functions provide:
-   computation of multiresolution quantities
-   local univariate and bivariate multifractal analysis 
-   linear regression and statistical modeling
-   visualization routines


## Installation

If you are using pip, you can install lompy as: 

pip install lompy 

## Examples 

A link to the notebook tutorials demonstrates in great detail the analysis both in a univariate and bivariate context:
https://gitlab.com/sroux67/LomPy/-/tree/main/tutorials

## Copyright

Copyright (C) 2023 GNU AGPLv3, LomPy 2023, S.G. Roux and J. Lengyel.
